@@ -56,7 +56,7 @@ def finish(
             if os.getenv("USING_EDGEDB", None):
                 print("NO EXT BUT EDGEDB")
             else:
-                print("NO EXT and not edgedb", j)
+                print("NO EXT and not edgedb")
     except Exception as e:
         print(f"ERRORED with {e=} IN FINISH, {j=}")
     if should_print:
