@@ -40,6 +40,9 @@ def model_dict_to_str(
     for field_name, val in d.items():
         type_cast_str = edgedb_conversion_map.get(field_name)
         if not type_cast_str:
+            # resolvers will come up here so ignore them
+            if field_name in set_links_d or val == set():
+                continue
             raise NodeException(f"{field_name=} not in {edgedb_conversion_map=}")
         variable_name = f"{field_name}{random_str(10)}"
         field_str = f"{field_name} := <{type_cast_str}>${variable_name}"
@@ -108,6 +111,12 @@ class Node(BaseModel, T.Generic[InsertType]):
 
     _edgedb_conversion_map: T.ClassVar[T.Dict[str, str]]
 
+    _extra: dict = PrivateAttr(default=dict())
+
+    @property
+    def extra(self) -> dict:
+        return self._extra
+
     class Config:
         validate_assignment = True
 
@@ -216,11 +225,12 @@ class Node(BaseModel, T.Generic[InsertType]):
             conflict_str = custom_on_conflict_str
         elif upsert_given_conflict_on:
             # replace s and variables
+            fields_to_exclude = (
+                set(insert.dict(exclude_none=True).keys())
+                - cls.GraphORM.updatable_fields
+            )
             update_s, update_variables = basemodel_to_str(
-                insert,
-                default_replace=True,
-                fields_to_exclude=set(insert.dict(exclude_none=True).keys())
-                - cls.GraphORM.updatable_fields,
+                insert, default_replace=True, fields_to_exclude=fields_to_exclude
             )
             variables.update(update_variables)
             conflict_str = f"UNLESS CONFLICT ON .{upsert_given_conflict_on} ELSE (UPDATE {cls._model_name} SET {update_s})"
