@@ -1,5 +1,5 @@
 # from dgraph_orm.resolver import get_fields_and_nested_fields
-from datetime import datetime
+from datetime import datetime, timedelta
 from zoneinfo import ZoneInfo
 from pydantic import BaseModel
 import time
@@ -423,10 +423,6 @@ async def test_transaction():
                 debug(p)
 
 
-async def test_extra_fields():
-    ...
-
-
 from dgraph_orm.vendors.edgedb.constants import random_str
 
 
@@ -542,24 +538,90 @@ async def add_lots_batch() -> float:
     return took
 
 
-async def main():
-    await test_get()
-    await test_nested()
-    await test_add()
-    await raw_add_test()
-    await test_raw_add_many()
-    await test_raw_insert_without_for_loop()
-    await test_delete()
-    await test_update()
-    await test_link()
-    await test_update_links()
-    await test_batch()
-    await test_refresh()
-    await test_transaction()
-    await test_upsert()
+async def test_extra_fields():
+    class CalendarBookingType(str, Enum):
+        external = "external"
+        internal = "internal"
 
-    await test_generated_add()
-    await test_generated_delete()
+    class CalendarBooking(BaseModel):
+        firebase_id: str
+        artist_name: str
+        # artist_profile_image: T.Optional[Image]
+        # artist_cover_image: T.Optional[Image]
+        start_time: datetime
+        booking_type: CalendarBookingType
+
+        # now for the click in fields
+        artist_bio: T.Optional[str] = None
+        public_event_description: T.Optional[str] = None
+        performance_length_mins: int
+        artist_slug: T.Optional[str] = None
+
+    start = datetime.now(tz=ZoneInfo("America/New_York"))
+    end = start + timedelta(days=90)
+    meta_bookings = (
+        await DB.MetaBookingResolver()
+        .filter(
+            ".is_published = <bool>$is_published AND .venue.slug = <str>$slug AND .start_time >= <datetime>$start AND .start_time <= <datetime>$end",
+            {
+                "start": start,
+                "end": end,
+                "slug": "beachcomberresort",
+                "is_published": True,
+            },
+        )
+        .order_by(".start_time asc")
+        .limit(100)
+        .offset(1)
+        .extra_fields(
+            "artist_name_external := [is ExternalBooking].artist_name, "
+            "artist_name := [is Booking].artist.name, artist_slug := [is Booking].artist.slug,"
+            "cover_photo_external := [is ExternalBooking].cover_image, "
+            "cover_image := [is Booking].artist.cover_image, artist_bio := [is Booking].artist.bio"
+        )
+        .query()
+    )
+    debug(meta_bookings)
+    calendar_bookings: T.List[CalendarBooking] = []
+    for meta in meta_bookings:
+        calendar_bookings.append(
+            CalendarBooking(
+                firebase_id=meta.firebase_id,
+                artist_name=meta.extra.get("artist_name_external")
+                or meta.extra.get("artist_name"),
+                start_time=meta.start_time,
+                booking_type=CalendarBookingType.internal
+                if meta.extra.get("artist_name")
+                else CalendarBookingType.external,
+                artist_bio=meta.extra.get("artist_bio"),
+                public_event_description=meta.public_event_description,
+                performance_length_mins=meta.performance_length_mins,
+                artist_slug=meta.extra.get("artist_slug"),
+            )
+        )
+    debug(calendar_bookings)
+
+
+async def main():
+    # await test_get()
+    # await test_nested()
+    # await test_add()
+    # await raw_add_test()
+    # await test_raw_add_many()
+    # await test_raw_insert_without_for_loop()
+    # await test_delete()
+    # await test_update()
+    # await test_link()
+    # await test_update_links()
+    # await test_batch()
+    # await test_refresh()
+    # await test_transaction()
+    # await test_upsert()
+    #
+    # await test_generated_add()
+    # await test_generated_delete()
+
+    await test_extra_fields()
 
     # expensive ones
     # await add_lots_async()
